@@ -15,7 +15,7 @@ console_handler.setFormatter(formatter)
 logger.addHandler(console_handler)
 
 DEBUG = False
-MOCK = False  # use mock data source
+MOCK = False
 
 
 @click.group()
@@ -42,6 +42,7 @@ def tui(addr=None, ch1=True, ch2=True):
     from uci_cbp_demo.bluetooth import SensorBoard
     pipe_1, pipe_2 = Pipe()
     tm = TerminalManager(pipe_1)
+
     sensor = SensorBoard(addr=addr, pipe=pipe_2)
 
     if ch1 and ch2:
@@ -59,7 +60,7 @@ def tui(addr=None, ch1=True, ch2=True):
     tm.handle_session()
 
 
-@cli.command()  # @cli, not @click!
+@cli.command()
 @click.option('-a', default=1, help='Scaling coefficient')
 @click.option('-b', default=0, help='Shifting in Y')
 @click.option('--ch1/--no-ch1', default=True)
@@ -70,7 +71,7 @@ def gui(a=1, b=0, ch1=True, ch2=True, addr=None):
     gui(a, b, ch1, ch2, addr)
 
 
-@cli.command()  # @cli, not @click!
+@cli.command()
 def scan():
     import asyncio
     from bleak import discover
@@ -84,7 +85,7 @@ def scan():
     loop.run_until_complete(run())
 
 
-@cli.command()  # @cli, not @click!
+@cli.command()
 @click.option('--addr', default=None)
 def list_char(addr):
     import asyncio
